@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 module Grape
   class Entity
     module Condition
       class BlockCondition < Base
         attr_reader :block
 
-        def setup(&block)
+        def setup(block)
           @block = block
         end
 
