@@ -4,7 +4,7 @@ module Grape
   class Entity
     module Delegator
       class FetchableObject < Base
-        def delegate(attribute, **)
+        def delegate(attribute)
           object.fetch attribute
         end
       end
