@@ -105,7 +105,7 @@ module Grape
         @root_exposure ||= Exposure.new(nil, nesting: true)
       end
 
-      attr_writer :root_exposure
+      attr_writer :root_exposure, :formatters
 
       # Returns all formatters that are registered for this and it's ancestors
       # @return [Hash] of formatters
@@ -113,8 +113,6 @@ module Grape
         @formatters ||= {}
       end
 
-      attr_writer :formatters
-
       def hash_access
         @hash_access ||= :to_sym
       end
@@ -124,12 +122,14 @@ module Grape
           case value
           when :to_s, :str, :string
             :to_s
-          when :to_sym, :sym, :symbol
-            :to_sym
           else
             :to_sym
           end
       end
+
+      def delegation_opts
+        @delegation_opts ||= { hash_access: hash_access }
+      end
     end
 
     @formatters = {}
@@ -137,6 +137,8 @@ module Grape
     def self.inherited(subclass)
       subclass.root_exposure = root_exposure.dup
       subclass.formatters = formatters.dup
+
+      super
     end
 
     # This method is the primary means by which you will declare what attributes
@@ -151,7 +153,7 @@ module Grape
     #
     # @example as: a proc or lambda
     #
-    #   object = OpenStruct(awesomness: 'awesome_key', awesome: 'not-my-key', other: 'other-key' )
+    #   object = OpenStruct(awesomeness: 'awesome_key', awesome: 'not-my-key', other: 'other-key' )
     #
     #   class MyEntity < Grape::Entity
     #     expose :awesome, as: proc { object.awesomeness }
@@ -518,6 +520,11 @@ module Grape
       else
         instance_exec(object, options, &block)
       end
+    rescue StandardError => e
+      # it handles: https://github.com/ruby/ruby/blob/v3_0_0_preview1/NEWS.md#language-changes point 3, Proc
+      raise Grape::Entity::Deprecated.new e.message, 'in ruby 3.0' if e.is_a?(ArgumentError)
+
+      raise e
     end
 
     def exec_with_attribute(attribute, &block)
@@ -531,8 +538,10 @@ module Grape
     def delegate_attribute(attribute)
       if is_defined_in_entity?(attribute)
         send(attribute)
+      elsif delegator.accepts_options?
+        delegator.delegate(attribute, **self.class.delegation_opts)
       else
-        delegator.delegate(attribute, hash_access: self.class.hash_access)
+        delegator.delegate(attribute)
       end
     end
 
@@ -573,6 +582,7 @@ module Grape
       merge
       expose_nil
       override
+      default
     ].to_set.freeze
 
     # Merges the given options with current block options.
