@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Grape
   class Entity
     module Exposure
@@ -5,6 +7,7 @@ module Grape
         attr_reader :using_class_name, :subexposure
 
         def setup(using_class_name, subexposure)
+          @using_class = nil
           @using_class_name = using_class_name
           @subexposure = subexposure
         end
@@ -20,7 +23,7 @@ module Grape
         end
 
         def value(entity, options)
-          new_options = options.for_nesting(key)
+          new_options = options.for_nesting(key(entity))
           using_class.represent(@subexposure.value(entity, options), new_options)
         end
 
