@@ -13,7 +13,7 @@ SimpleCov.start do
   add_filter 'spec/'
 end
 
-Coveralls.wear!
+Coveralls.wear! unless RUBY_PLATFORM.eql? 'java'
 
 $LOAD_PATH.unshift(File.dirname(__FILE__))
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
